summaryrefslogtreecommitdiff
path: root/app/models
diff options
context:
space:
mode:
Diffstat (limited to 'app/models')
-rw-r--r--app/models/ability.rb3
1 files changed, 2 insertions, 1 deletions
diff --git a/app/models/ability.rb b/app/models/ability.rb
index 0fa40c8..cd91a8a 100644
--- a/app/models/ability.rb
+++ b/app/models/ability.rb
@@ -74,9 +74,10 @@ class Ability
cannot :manage, PhoneNumberRange
end
# GsParameter can't be created or deleted via the GUI
#
cannot [:create, :destroy], GsParameter
+ cannot [:create, :destroy], GuiFunction
else
# Any user can do the following stuff.
#
@@ -74,9 +74,10 @@ class Ability
cannot :manage, PhoneNumberRange
end
- # GsParameter can't be created or deleted via the GUI
+ # GsParameter and GuiFunction can't be created or deleted via the GUI
#
cannot [:create, :destroy], GsParameter